pub struct UnfulfillablePreviewItem {
    pub seller_sku: String,
    pub quantity: i32,
    pub seller_fulfillment_order_item_id: String,
    pub item_unfulfillable_reasons: Option<Vec<String>>,
}
UnfulfillablePreviewItem : Information about unfulfillable items in a fulfillment order preview.

Fields

seller_sku: String

The seller SKU of the item.

quantity: i32

The item quantity.

seller_fulfillment_order_item_id: String

A fulfillment order item identifier created with a call to the getFulfillmentPreview operation.

item_unfulfillable_reasons: Option<Vec<String>>

Implementations

Information about unfulfillable items in a fulfillment order preview.