Struct amazon_sp_fulfillment_outbound::models::unfulfillable_preview_item::UnfulfillablePreviewItem
source · [−]pub struct UnfulfillablePreviewItem {
pub seller_sku: String,
pub quantity: i32,
pub seller_fulfillment_order_item_id: String,
pub item_unfulfillable_reasons: Option<Vec<String>>,
}Expand description
UnfulfillablePreviewItem : Information about unfulfillable items in a fulfillment order preview.
Fields
seller_sku: StringThe seller SKU of the item.
quantity: i32The item quantity.
seller_fulfillment_order_item_id: StringA fulfillment order item identifier created with a call to the getFulfillmentPreview operation.
item_unfulfillable_reasons: Option<Vec<String>>Implementations